NengoDL
=======

.. toctree::
    :maxdepth: 3

    Introduction <introduction>
    installation
    frontend
    examples
    resources
    backend
    project

`Github <https://github.com/nengo/nengo-dl>`_ |
`PyPI <https://pypi.python.org/pypi/nengo-dl>`_